@@ -1,13 +1,13 @@
+import json
 import math
 from typing import Any, Dict
 
 import pytest
-
 from kisters.network_store.model_library.util import (
     all_links,
     all_nodes,
     element_from_dict,
-    element_to_dict,
+    # element_to_dict,
     elements_mapping,
 )
 
@@ -76,11 +76,8 @@ elements = [
         "source_uid": "junction",
         "target_uid": "storage",
         "hydrologic_routing": {
-            "model": "muskingum-cunge",
-            "stations": [
-                {"k": 100.0, "x": 100.0, "distance": 25.0},
-                {"k": 100.0, "x": 100.0, "distance": 75.0},
-            ],
+            "muskingum_station": {"model": "muskingum", "k": 100.0, "x": 0.4},
+            "reservoir_station": {"model": "reservoir", "p": 2.0, "m": 1.0},
         },
         "length": 100.0,
         "display_name": "channel",
@@ -100,8 +97,11 @@ elements = [
         "source_uid": "junction",
         "target_uid": "storage",
         "hydrologic_routing": {
-            "model": "muskingum-cunge",
-            "stations": {"k": 100.0, "x": 100.0},
+            "reservoir_station": {
+                "model": "reservoir",
+                "p": 2.0,
+                "m": 1.0,
+            }
         },
         "length": 100.0,
         "display_name": "channel",
@@ -295,6 +295,7 @@ elements = [
         "display_name": "storage",
         "schematic_location": {"x": 1.0, "y": 1.0, "z": 0.0},
         "element_class": "Storage",
+        "flow_boundary": False,
         "collection": "nodes",
         "domain": "water",
     },
@@ -384,8 +385,8 @@ bad_elements = [
         "source_uid": "junction",
         "target_uid": "storage",
         "hydrologic_routing": {
-            "model": "muskingum-cunge",
-            "stations": {"k": 100.0, "x": 100.0, "distance": 25.0},
+            "model": "muskingum",
+            "stations": {"model": "muskingum", "k": 100.0, "x": 100.0},
         },
         "length": 100.0,
         "display_name": "channel",
@@ -399,7 +400,9 @@ bad_elements = [
         "target_uid": "storage",
         "hydrologic_routing": {
             "model": "muskingum-cunge",
-            "stations": [{"k": 100.0, "x": 100.0}],
+            "stations": {
+                "muskingum-cunge": {"model": "muskingum-cunge", "k": 100.0, "x": 100.0}
+            },
         },
         "length": 100.0,
         "display_name": "channel",
@@ -412,11 +415,8 @@ bad_elements = [
         "source_uid": "junction",
         "target_uid": "storage",
         "hydrologic_routing": {
-            "model": "muskingum-cunge",
-            "stations": [
-                {"k": 100.0, "x": 100.0, "distance": 50.0},
-                {"k": 100.0, "x": 100.0, "distance": 50.0},
-            ],
+            "model": "muskingum",
+            "stations": {"muskingum": {"model": "muskingum", "k": 100.0, "x": 100.0}},
         },
         "length": 100.0,
         "display_name": "channel",
@@ -501,11 +501,8 @@ bad_elements = [
         "source_uid": "junction",
         "target_uid": "storage",
         "hydrologic_routing": {
-            "model": "muskingum-cunge",
-            "stations": [
-                {"k": 100.0, "x": 100.0, "distance": 25.0},
-                {"k": 100.0, "x": 100.0, "distance": 101.0},
-            ],
+            "model": "muskingum",
+            "stations": {"muskingum": {"model": "muskingum", "k": 100.0, "x": 100.0}},
         },
         "length": 100.0,
         "display_name": "channel",
@@ -771,7 +768,7 @@ bad_elements = [
 @pytest.mark.parametrize("element", elements)
 def test_parse(element: Dict[str, Any]) -> None:
     instance = element_from_dict(element)
-    reserialised = element_to_dict(instance)
+    reserialised = json.loads(instance.json(exclude_none=True, exclude_unset=True))
     assert element == reserialised
 
 
